@@ -290,7 +290,7 @@ class DeploySatchel(ContainerSatchel):
 
             if last_commit and current_commit:
                 # Show tickets between last deployment and now.
-                tickets = jirahelper.get_tickets_between_commits(current_commit, last_commit)
+                tickets = jirahelper.get_tickets_between_commits(last_commit, current_commit)
                 print('\nIssues to be deployed: {}\n'.format(', '.join(tickets) or 'None'))
 
         if ask and self.genv.host_string == self.genv.hosts[-1]:
@@ -317,8 +317,9 @@ class DeploySatchel(ContainerSatchel):
         yes = int(yes)
         show_preview = not yes or int(show_preview)
         show_issues = int(show_issues)
-        self.lock()
+
         try:
+            self.lock() # Ensure that no one else can concurrently deploy to these hosts.
 
             if show_preview:
                 # If we want to confirm the deployment with the user, and we're at the first server,
