@@ -37,7 +37,6 @@ class PIPSatchel(Satchel):
         self.env.perms = '775'
         self.env.virtualenv_dir = '.env'
         self.env.requirements = 'pip-requirements.txt'
-        self.env.quiet_flag = '-q'
         self.env.python_version = '3.7'
 
     @task
@@ -160,6 +159,7 @@ class PIPSatchel(Satchel):
     @task
     def update_install(self, **kwargs):
         r = self.local_renderer
+        r.env.quiet_flag = '' if self.verbose else '-q'
 
         options = [
             'requirements',
