@@ -437,6 +437,8 @@ class PostgreSQLSatchel(DatabaseSatchel):
         site = site or self.genv.SITE
         drop_other_usenames = int(drop_other_usenames)
 
+        print('Dropping database connections...')
+
         r = self.database_renderer(name=name, site=site)
         external_ip = (r.run('wget http://ipecho.net/plain -O - -q ; echo') or '').strip()
         if r.env.db_root_username == 'postgres' and r.env.db_host == external_ip:
@@ -594,13 +596,13 @@ class PostgreSQLSatchel(DatabaseSatchel):
             v = r.env.version_command
         else:
             v = (r.run('echo {version_command}') or '').strip()
-        print('postgresql version:', v)
+        self.vprint('postgresql version:', v)
 
         # Postgres 10+ doesn't use minor version in /etc/postgresql/ subdirectory names
-        if not v.startswith('9'):
+        if isinstance(v, str) and not v.startswith('9'):
             v = v.split('.')[0]
 
-        print('postgresql subdirectory version:', v)
+        self.vprint('postgresql subdirectory version:', v)
         return v
 
     @task
